LabelBean class

标签打印

Constructors

LabelBean({String? companyName, required String waybillUuid, required String shipper, required String shipperAddressDetail, required String shipperAreaName, required String consignee, required String consigneeAddressDetail, required String consigneeAreaName, required String serviceModeName, required String productTypeName, required String packagingTypeName, required String printTime, required String fromSiteName, required String dispatchSiteName, required String transitSiteName, required int totalCount})

Properties

companyName String?
final
companyNameFormat String
no setter
consignee String
final
consigneeAddressDetail String
final
consigneeAreaName String
final
consigneeFormat String
no setter
dispatchSiteName String
final
dispatchSiteNameFormat String
no setter
fromSiteName String
final
fromSiteNameFormat String
no setter
hashCode int
The hash code for this object.
no setterinherited
packagingTypeName String
final
packagingTypeNameFormat String
no setter
printTime String
final
productTypeName String
final
productTypeNameFormat String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceModeName String
final
serviceModeNameFormat String
no setter
shipper String
final
shipperAddressDetail String
final
shipperAreaName String
final
shipperFormat String
no setter
totalCount int
final
transitSiteName String
final
transitSiteNameFormat String
no setter
waybillUuid String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subString(String value, int length) String
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited