ReceiptBean class

面单(收据)打印

Constructors

ReceiptBean({String? companyName, required String cellPhoneNumber, required String waybillUuid, required String shipper, required String shipperAddressProvinceName, required String shipperAddressCityName, required String shipperAddressDistrictName, required String shipperPhone, required String shipperLandline, required String shipperAddressFull, required String consignee, required String consigneeAddressProvinceName, required String consigneeAddressCityName, required String consigneeAddressDistrictName, required String consigneePhone, required String consigneeLandline, required String consigneeAddressFull, required String cargoName, required String packagingTypeName, required int totalCount, required int totalVolume, required int totalWeight, required String serviceModeName, required String payTypeName, required int freightFees, required int unloadingFees, required int deliveryFees, required bool deliveryNotice, required int totalFees, required int collectFees, required int informationFees, required String receiptNo, required int receiptCount, required String remark, required String printTime, required int signRequirement, required int payType, required int arriveFees})

Properties

arriveFees int
final
arriveFeesFormat double
no setter
cargoName String
final
cargoNameFormat String
no setter
cellPhoneNumber String
final
collectFees int
final
collectFeesFormat double
no setter
companyName String?
final
companyNameFormat String
no setter
consignee String
final
consigneeAddressCityName String
final
consigneeAddressCityNameFormat String
no setter
consigneeAddressDistrictName String
final
consigneeAddressDistrictNameFormat String
no setter
consigneeAddressFull String
final
consigneeAddressProvinceName String
final
consigneeAddressProvinceNameFormat String
no setter
consigneeLandline String
final
consigneePhone String
final
deliveryFees int
final
deliveryFeesFormat double
no setter
deliveryNotice bool
final
freightFees int
final
freightFeesFormat double
no setter
hashCode int
The hash code for this object.
no setterinherited
informationFees int
final
informationFeesFormat double
no setter
packagingTypeName String
final
payType int
final
payTypeName String
final
printTime String
final
receiptCount int
final
receiptNo String
final
remark String
final
remarkFormat String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serviceModeName String
final
shipper String
final
shipperAddressCityName String
final
shipperAddressCityNameFormat String
no setter
shipperAddressDistrictName String
final
shipperAddressDistrictNameFormat String
no setter
shipperAddressFull String
final
shipperAddressProvinceName String
final
shipperAddressProvinceNameFormat String
no setter
shipperLandline String
final
shipperPhone String
final
signRequirement int
final
totalCount int
final
totalFees int
final
totalFeesFormat double
no setter
totalVolume int
final
totalVolumeFormat String
no setter
totalWeight int
final
unloadingFees int
final
unloadingFeesFormat double
no setter
waybillUuid String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
subString(String value, int length) String
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited