CalculateUtil class

Constructors

CalculateUtil()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

centToYuan(int? l) double
cmToM(int? l) double
dmToM(int? l) String
kgToTon(int? w) double
mToCM(double? l) int
tonToKg(double? w) int
yuanToCent(double? l) int